@@ -1,9 +1,12 @@
 from datetime import datetime
 from enum import Enum
+from typing import Optional
 
 from .account import Account
 from .base import BaseModel
 
+__all__ = ["Organization", "OrganizationRole", "OrganizationMember"]
+
 
 class Organization(BaseModel):
     id: str
@@ -11,6 +14,7 @@ class Organization(BaseModel):
     description: str
     created: datetime
     display_name: str
+    pronouns: Optional[str] = None
 
 
 class OrganizationRole(str, Enum):
