@@ -10,6 +10,7 @@ Exceptions that can be raised by the :class:`~beaker.Beaker` client.
 from pydantic import ValidationError  # noqa: F401, re-imported here for convenience
 from requests.exceptions import (  # noqa: F401, re-imported here for convenience
     HTTPError,
+    RequestException,
 )
 
 ValidationError.__doc__ = """
@@ -17,6 +18,46 @@ Raised when data passed into a :mod:`DataModel <beaker.data_model>` is invalid.
 """
 
 
+__all__ = [
+    "BeakerError",
+    "ValidationError",
+    "HTTPError",
+    "RequestException",
+    "NotFoundError",
+    "AccountNotFound",
+    "OrganizationNotFound",
+    "OrganizationNotSet",
+    "ConfigurationError",
+    "ImageNotFound",
+    "ImageConflict",
+    "WorkspaceNotFound",
+    "WorkspaceWriteError",
+    "WorkspaceConflict",
+    "ClusterNotFound",
+    "ClusterConflict",
+    "ExperimentNotFound",
+    "ExperimentConflict",
+    "DatasetConflict",
+    "DatasetNotFound",
+    "UnexpectedEOFError",
+    "JobNotFound",
+    "WorkspaceNotSet",
+    "NodeNotFound",
+    "DatasetWriteError",
+    "DatasetReadError",
+    "SecretNotFound",
+    "GroupConflict",
+    "GroupNotFound",
+    "DuplicateJobError",
+    "DuplicateExperimentError",
+    "TaskNotFound",
+    "ChecksumFailedError",
+    "TaskStoppedError",
+    "JobFailedError",
+    "JobTimeoutError",
+]
+
+
 class BeakerError(Exception):
     """
     Base class for all Beaker errors other than :exc:`HTTPError`, which is re-exported
@@ -25,11 +66,17 @@ class BeakerError(Exception):
     """
 
 
-class AccountNotFound(BeakerError):
+class NotFoundError(BeakerError):
+    """
+    Base class for all "not found" error types.
+    """
+
+
+class AccountNotFound(NotFoundError):
     pass
 
 
-class OrganizationNotFound(BeakerError):
+class OrganizationNotFound(NotFoundError):
     """
     Raised when a specified organization doesn't exist.
     """
@@ -48,7 +95,7 @@ class ConfigurationError(BeakerError):
     """
 
 
-class ImageNotFound(BeakerError):
+class ImageNotFound(NotFoundError):
     pass
 
 
@@ -58,7 +105,7 @@ class ImageConflict(BeakerError):
     """
 
 
-class WorkspaceNotFound(BeakerError):
+class WorkspaceNotFound(NotFoundError):
     pass
 
 
@@ -74,7 +121,7 @@ class WorkspaceConflict(BeakerError):
     """
 
 
-class ClusterNotFound(BeakerError):
+class ClusterNotFound(NotFoundError):
     pass
 
 
@@ -84,7 +131,7 @@ class ClusterConflict(BeakerError):
     """
 
 
-class ExperimentNotFound(BeakerError):
+class ExperimentNotFound(NotFoundError):
     pass
 
 
@@ -100,7 +147,7 @@ class DatasetConflict(BeakerError):
     """
 
 
-class DatasetNotFound(BeakerError):
+class DatasetNotFound(NotFoundError):
     pass
 
 
@@ -110,7 +157,7 @@ class UnexpectedEOFError(BeakerError):
     """
 
 
-class JobNotFound(BeakerError):
+class JobNotFound(NotFoundError):
     pass
 
 
@@ -120,7 +167,7 @@ class WorkspaceNotSet(BeakerError):
     """
 
 
-class NodeNotFound(BeakerError):
+class NodeNotFound(NotFoundError):
     pass
 
 
@@ -137,7 +184,7 @@ class DatasetReadError(BeakerError):
     """
 
 
-class SecretNotFound(BeakerError):
+class SecretNotFound(NotFoundError):
     pass
 
 
@@ -147,7 +194,7 @@ class GroupConflict(BeakerError):
     """
 
 
-class GroupNotFound(BeakerError):
+class GroupNotFound(NotFoundError):
     pass
 
 
@@ -163,7 +210,7 @@ class DuplicateExperimentError(BeakerError):
     """
 
 
-class TaskNotFound(BeakerError):
+class TaskNotFound(NotFoundError):
     pass
 
 
