@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Dict, Optional, Union
+from typing import TYPE_CHECKING, Dict, Optional, Union, cast
 
 from docker.models.images import Image as DockerImage
 
@@ -22,7 +22,8 @@ class ImageClient(ServiceClient):
         :param image: The Beaker image ID or name.
 
         :raises ImageNotFound: If the image can't be found on Beaker.
-        :raises HTTPError: Any other HTTP exception that can occur.
+        :raises RequestException: Any other exception that can occur when contacting the
+            Beaker server.
         """
 
         def _get(id: str) -> Image:
@@ -70,14 +71,15 @@ class ImageClient(ServiceClient):
         :raises WorkspaceNotSet: If neither ``workspace`` nor
             :data:`Beaker.config.default_workspace <beaker.Config.default_workspace>` are set.
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
-        :raises HTTPError: Any other HTTP exception that can occur.
+        :raises RequestException: Any other exception that can occur when contacting the
+            Beaker server.
 
         """
         self.validate_beaker_name(name)
         workspace = self.resolve_workspace(workspace)
 
         # Get local Docker image object.
-        image = self.docker.images.get(image_tag)
+        image = cast(DockerImage, self.docker.images.get(image_tag))
 
         # Create new image on Beaker.
         image_id = self.request(
@@ -176,7 +178,8 @@ class ImageClient(ServiceClient):
 
         :raises ImageNotFound: If the image can't be found on Beaker.
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
-        :raises HTTPError: Any other HTTP exception that can occur.
+        :raises RequestException: Any other exception that can occur when contacting the
+            Beaker server.
         """
         image_id = self.resolve_image(image).id
         return Image.from_json(
@@ -196,7 +199,8 @@ class ImageClient(ServiceClient):
 
         :raises ImageNotFound: If the image can't be found on Beaker.
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
-        :raises HTTPError: Any other HTTP exception that can occur.
+        :raises RequestException: Any other exception that can occur when contacting the
+            Beaker server.
         """
         image_id = self.resolve_image(image).id
         self.request(
@@ -216,7 +220,8 @@ class ImageClient(ServiceClient):
         :raises ValueError: If the image name is invalid.
         :raises ImageConflict: If an image with the given name already exists.
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
-        :raises HTTPError: Any other HTTP exception that can occur.
+        :raises RequestException: Any other exception that can occur when contacting the
+            Beaker server.
         """
         self.validate_beaker_name(name)
         image_id = self.resolve_image(image).id
@@ -242,7 +247,8 @@ class ImageClient(ServiceClient):
 
         :raises ImageNotFound: If the image can't be found on Beaker.
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
-        :raises HTTPError: Any other HTTP exception that can occur.
+        :raises RequestException: Any other exception that can occur when contacting the
+            Beaker server.
         """
         image_id = self.resolve_image(image).id
         repo = ImageRepo.from_json(self.request(f"images/{image_id}/repository").json())
@@ -312,7 +318,7 @@ class ImageClient(ServiceClient):
                         completed=1,
                     )
 
-        local_image = self.docker.images.get(repo.image_tag)
+        local_image = cast(DockerImage, self.docker.images.get(repo.image_tag))
         return local_image
 
     def url(self, image: Union[str, Image]) -> str:
