@@ -10,7 +10,6 @@ from ..config import Config
 from ..data_model import *
 from ..exceptions import *
 from ..util import retriable
-from ..version import VERSION
 
 if TYPE_CHECKING:
     from ..client import Beaker
@@ -52,7 +51,7 @@ class ServiceClient:
             default_headers = {
                 "Authorization": f"Bearer {token or self.config.user_token}",
                 "Content-Type": "application/json",
-                "User-Agent": f"beaker-py v{VERSION}",
+                "User-Agent": self.beaker.user_agent,
             }
             if headers is not None:
                 default_headers.update(headers)
